package App::Egaz;

our $VERSION = "0.0.8";

use strict;
use warnings;
use App::Cmd::Setup -app;

1;
__END__

=encoding utf-8

=head1 NAME

App::Egaz - It's new $module

=head1 SYNOPSIS

    use App::Egaz;

=head1 DESCRIPTION

App::Egaz is ...

=head1 LICENSE

Copyright (C) wang-q.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

wang-q E<lt>wang-q@outlook.comE<gt>

=cut

